<?php

namespace Trackeasy\Classes;

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * TE_Trackeasy_REST_Client class
 */
class TE_Trackeasy_REST_Client
{
    /**
     * Sends a request to the TrackEasy API.
     *
     * @param int $api_key
     * @param int $campaign_id
     * @param array $data
     * @return void
     * @access public
     * @static
     */
    public static function te_send_request(int $api_key, int $campaign_id, array $data = []): void
    {
        $json_data = json_encode([
            'apiKey' => $api_key,
            'campaignid' => $campaign_id,
            ...self::te_field_mapper($data)
        ]);

        error_log(sprintf(__('%s data posted: %s', 'trackeasy'), 'TrackEasy cURL JSON', print_r($json_data, true)));

        $endpoint = 'https://admin.trackeasy.co.za/WebService/CustomEndPoints.asmx/addJsonLead';
        $ch = curl_init($endpoint);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json_data);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Content-Length: ' . strlen($json_data)
        ]);

        $response = curl_exec($ch);

        if (curl_errno($ch)) {
            $error_message = curl_error($ch);
            error_log(sprintf(__('%s error: %s', 'trackeasy'), 'TrackEasy cURL', $error_message));
        } else {
            error_log(sprintf(__('%s response: %s', 'trackeasy'), 'TrackEasy cURL', print_r($response, true)));
        }

        curl_close($ch);
    }

    /**
     * Maps the form fields to the TrackEasy API addJsonLead fields.
     *
     * @param array $data
     * @return array
     * @access private
     * @static
     */
    private static function te_field_mapper(array $data): array
    {
        $mapped_fields = [];

        foreach(TE_Trackeasy_Fields::get_fields() as $field) {
            if (isset($data[$field['name']]) && !empty($data[$field['name']]['value'])) {
                if (isset($field['type']) && $field['type'] === 'acceptance') {
                    $mapped_fields[$field['name']] = (int) TE_Trackeasy_Sanitiser::te_sanitise_field_value($field['type'], $data[$field['name']]['value']);
                } else {
                    $mapped_fields[$field['name']] = $data[$field['name']]['value'];
                }
            } else {
                $mapped_fields[$field['name']] = $field['default_value'];
            }
        }

        return $mapped_fields;
    }
}
