<?php

namespace Trackeasy\Classes;

/**
 * TE_Trackeasy_Sanitiser class
 */
class TE_Trackeasy_Sanitiser
{
    /**
     * Sanitises and returns a field value
     *
     * @param string $field_type
     * @param string|array $field_value
     * @return string|int
     * @access private
     * @static
     */
    public static function te_sanitise_field_value(string $field_type, string|array $field_value): string
    {
        $sanitised_value = '';

        switch (true) {
            case $field_type === 'text'
                || $field_type === 'tel'
                || $field_type === 'number'
                || $field_type === 'date'
                || $field_type === 'quiz'
                || $field_type === 'hidden'
                || $field_type === 'password':
                $sanitised_value = sanitize_text_field($field_value);
                break;
            case $field_type === 'email':
                $sanitised_value = sanitize_email($field_value);
                break;
            case $field_type === 'url':
                $sanitised_value = sanitize_url($field_value);
                break;
            case $field_type === 'textarea':
                $sanitised_value = sanitize_textarea_field($field_value);
                break;
            case $field_type === 'checkbox'
                || $field_type === 'select'
                || $field_type === 'radio':
                $sanitised_value = sanitize_text_field(implode(', ', $field_value));
                break;
            case $field_type === 'acceptance':
                if (TE_Trackeasy_Validator::te_string_is_int_val_0_or_1(sanitize_text_field($field_value))) {
                    $sanitised_value = $field_value;
                } else {
                    $sanitised_value = '0';
                }
                break;
        }

        return $sanitised_value;
    }

    /**
     * Returns an array of sanitised form field values
     *
     * @param array $fields
     * @return void
     * @access public
     * @static
     */
    public static function te_sanitise_field_values(array &$fields): void
    {
        if (!empty($fields)) {
            foreach($fields as &$field) {
                $field['value'] = self::te_sanitise_field_value($field['type'], $field['value']);
            }
        }
    }
}
